@@ -1,5 +1,5 @@
 package Beam::Make;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 # ABSTRACT: Recipes to declare and resolve dependencies between things
 
 #pod =head1 SYNOPSIS
@@ -280,7 +280,7 @@ sub run( $self, @argv ) {
         else {
             $result = $LOG->info( "$target up-to-date (modified: " . $recipe->last_modified . ")" );
         }
-        if ( !@target_stack ) {
+        if ( !@target_stack && !$LOG->is_info ) {
             # We were directly asked to build this, so let the user
             # know about it
             say $result;
@@ -343,7 +343,7 @@ Beam::Make - Recipes to declare and resolve dependencies between things
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
